@@ -3,7 +3,7 @@
 import pluggy
 
 import moe
-from moe.config import Config
+from moe import config
 
 from . import edit_cli, edit_core
 from .edit_core import *
@@ -13,8 +13,8 @@ __all__.extend(edit_core.__all__)
 
 
 @moe.hookimpl
-def plugin_registration(config: Config):
+def plugin_registration():
     """Only register the cli sub-plugin if the cli is enabled."""
-    config.plugin_manager.register(edit_core, "edit_core")
-    if config.plugin_manager.has_plugin("cli"):
-        config.plugin_manager.register(edit_cli, "edit_cli")
+    config.CONFIG.pm.register(edit_core, "edit_core")
+    if config.CONFIG.pm.has_plugin("cli"):
+        config.CONFIG.pm.register(edit_cli, "edit_cli")
