@@ -5,9 +5,10 @@ import re
 import shutil
 from contextlib import suppress
 from pathlib import Path
-from typing import Union
+from typing import Callable, Union
 
 import dynaconf
+import pluggy
 from unidecode import unidecode
 
 import moe
@@ -19,13 +20,38 @@ __all__ = ["copy_item", "fmt_item_path", "move_item"]
 log = logging.getLogger("moe.move")
 
 
+class Hooks:
+    """Move plugin hook specifications."""
+
+    @staticmethod
+    @moe.hookspec
+    def create_path_template_func() -> list[Callable]:  # type: ignore
+        """Create a custom path template function.
+
+        Any functions returned by this hook will be available to be called from within
+        the path templates defined by the move plugin.
+
+        Returns:
+            A list of all custom path functions your plugin creates. The list should
+            contain the callable functions themselves.
+        """  # noqa: DAR202
+
+
+@moe.hookimpl
+def add_hooks(pm: pluggy.manager.PluginManager):
+    """Registers `add` hookspecs to Moe."""
+    from moe.plugins.move.move_core import Hooks
+
+    pm.add_hookspecs(Hooks)
+
+
 @moe.hookimpl
 def add_config_validator(settings: dynaconf.base.LazySettings):
     """Validate move plugin configuration settings."""
     default_album_path = "{album.artist}/{album.title} ({album.year})"
-    default_extra_path = "{extra.path.name}"
+    default_extra_path = "{e_unique(extra)}"
     default_track_path = (
-        "{f'Disc {track.disc:02}' if track.disc_total > 1 else ''}/"
+        "{f'Disc {track.disc:02}' if album.disc_total > 1 else ''}/"
         "{track.track_num:02} - {track.title}{track.path.suffix}"
     )
 
@@ -45,6 +71,22 @@ def edit_new_items(items: list[LibItem]):
         copy_item(item)
 
 
+@moe.hookimpl
+def create_path_template_func() -> list[Callable]:
+    """Adds custom functions for the path templates."""
+    return [e_unique]
+
+
+def e_unique(extra: Extra) -> str:
+    """Returns a unique filename for an extra within its album."""
+    extra_names = [album_extra.path.name for album_extra in extra.album_obj.extras]
+
+    if (name_count := extra_names.count(extra.path.name)) > 1:
+        return extra.path.stem + f" ({name_count - 1})" + extra.path.suffix
+
+    return extra.path.name
+
+
 ########################################################################################
 # Format paths
 ########################################################################################
@@ -142,11 +184,18 @@ def _lazy_fstr_item(template: str, lib_item: LibItem) -> str:
         album = lib_item  # noqa: F841
     elif isinstance(lib_item, Track):
         track = lib_item  # noqa: F841
+        album = track.album_obj
     elif isinstance(lib_item, Extra):
         extra = lib_item  # noqa: F841
+        album = extra.album_obj  # noqa: F841
     else:
         raise NotImplementedError
 
+    plugin_funcs = config.CONFIG.pm.hook.create_path_template_func()
+    for funcs in plugin_funcs:
+        for func in funcs:
+            globals()[func.__name__] = func
+
     return eval(f'f"""{template}"""')
 
 
