@@ -17,7 +17,7 @@ See Also:
 import datetime
 import logging
 from pathlib import Path
-from typing import Any, Callable, Optional
+from typing import Any, Callable, Optional, cast
 
 import dynaconf
 import mediafile
@@ -26,7 +26,7 @@ import pkg_resources
 
 import moe
 from moe import config
-from moe.library import Album, LibItem, Track
+from moe.library import Album, LibItem, MetaAlbum, MetaTrack, Track
 from moe.plugins.moe_import.import_core import CandidateAlbum
 from moe.util.core import match
 
@@ -126,12 +126,25 @@ def get_candidates(album: Album) -> list[CandidateAlbum]:
         A new album containing all the corrected metadata from musicbrainz. Note, this
         album is not complete, as it will not contain any references to the filesystem.
     """
-    log.debug(f"Getting candidate albums from musicbrainz. [{album=!r}")
+    log.debug(f"Getting candidate albums from musicbrainz. [{album=!r}]")
 
     search_criteria: dict = {}
     search_criteria["artist"] = album.artist
     search_criteria["release"] = album.title
     search_criteria["date"] = album.date.isoformat()
+    search_criteria["mediums"] = album.disc_total
+    if album.barcode:
+        search_criteria["barcode"] = album.barcode
+    if album.catalog_nums:
+        search_criteria["catno"] = next(iter(album.catalog_nums))  # get any cat_num
+    if album.label:
+        search_criteria["label"] = album.label
+    if album.mb_album_id:
+        search_criteria["reid"] = album.mb_album_id
+    if album.media:
+        search_criteria["format"] = album.media
+    if album.track_total:
+        search_criteria["tracks"] = album.track_total
 
     releases = musicbrainzngs.search_releases(limit=5, **search_criteria)
 
@@ -200,6 +213,7 @@ def sync_metadata(item: LibItem):
     if isinstance(item, Album) and hasattr(item, "mb_album_id"):
         item.merge(get_album_by_id(item.mb_album_id), overwrite=True)
     elif isinstance(item, Track) and hasattr(item, "mb_track_id"):
+        item = cast(Track, item)
         item.merge(
             get_track_by_id(item.mb_track_id, item.album_obj.mb_album_id),
             overwrite=True,
@@ -353,7 +367,7 @@ def set_collection(releases: set[str], collection: Optional[str] = None) -> None
     add_releases_to_collection(new_releases, collection)
 
 
-def get_album_by_id(release_id: str) -> Album:
+def get_album_by_id(release_id: str) -> MetaAlbum:
     """Returns an album from musicbrainz with the given release ID."""
     log.debug(f"Fetching release from musicbrainz. [release={release_id!r}]")
 
@@ -374,7 +388,9 @@ def get_candidate_by_id(album: Album, release_id: str) -> CandidateAlbum:
 
     candidate_album = _create_album(release)
 
-    sub_header_info = [str(_parse_date(release["date"]).year)]
+    sub_header_info = []
+    if date := _get_release_date(release):
+        sub_header_info.append(str(date.year))
     if disambiguation := release.get("disambiguation"):
         sub_header_info.append(disambiguation)
 
@@ -386,38 +402,45 @@ def get_candidate_by_id(album: Album, release_id: str) -> CandidateAlbum:
     )
 
 
-def _create_album(release: dict) -> Album:
+def _create_album(release: dict) -> MetaAlbum:
     """Creates an album from a given musicbrainz release."""
     log.debug(f"Creating album from musicbrainz release. [release={release['id']!r}]")
 
+    catalog_nums = set()
     if release["label-info-list"]:
         label = release["label-info-list"][0]["label"]["name"]
+        for label_info in release["label-info-list"]:
+            if label_info.get("catalog-number"):
+                catalog_nums.add(label_info["catalog-number"])
     else:
         label = None
+    if not catalog_nums:
+        catalog_nums = None
 
-    album = Album(
+    album = MetaAlbum(
         artist=_flatten_artist_credit(release["artist-credit"]),
+        barcode=release.get("barcode"),
+        catalog_nums=catalog_nums,
         country=release.get("country"),
-        date=_parse_date(release["date"]),
+        date=_get_release_date(release),
         disc_total=int(release["medium-count"]),
         label=label,
         mb_album_id=release["id"],
-        media=release["medium-list"][0]["format"],
-        original_date=_parse_date(release["release-group"]["first-release-date"]),
+        media=release["medium-list"][0].get("format"),
+        original_date=_get_original_date(release),
         title=release["title"],
-        path=None,  # type: ignore # this will get set in `add_prompt`
     )
     for medium in release["medium-list"]:
         for track in medium["track-list"]:
-            Track(
+            MetaTrack(
                 album=album,
                 track_num=int(track["position"]),
-                path=None,  # type: ignore # this will get set in `add_prompt`
                 artist=_flatten_artist_credit(track["recording"]["artist-credit"]),
                 disc=int(medium["position"]),
                 mb_track_id=track["id"],
                 title=track["recording"]["title"],
             )
+    album.track_total = len(album.tracks)
 
     log.debug(f"Created album from musicbrainz release. [{album=!r}]")
     return album
@@ -435,8 +458,25 @@ def _flatten_artist_credit(artist_credit: list[dict]) -> str:
     return full_artist
 
 
-def _parse_date(date: str) -> datetime.date:
+def _get_release_date(release: dict) -> Optional[datetime.date]:
+    """Gets the release date from a given musicbrainz release."""
+    date = release.get("date")
+    if date:
+        return _parse_date(date)
+
+    return _get_original_date(release)
+
+
+def _get_original_date(release: dict) -> Optional[datetime.date]:
+    """Gets the original release date from a given musicbrainz release."""
+    return _parse_date(release["release-group"]["first-release-date"])
+
+
+def _parse_date(date: Optional[str]) -> Optional[datetime.date]:
     """Parses a date from a musicbrainz release."""
+    if not date:
+        return None
+
     date_parts = date.split("-")
 
     year = int(date_parts[0])
@@ -452,7 +492,7 @@ def _parse_date(date: str) -> datetime.date:
     return datetime.date(year, month, day)
 
 
-def get_track_by_id(track_id: str, album_id: str) -> Track:
+def get_track_by_id(track_id: str, album_id: str) -> MetaTrack:
     """Gets a musicbrainz track from a given track and release id.
 
     Args:
