@@ -7,7 +7,7 @@ import pluggy
 
 import moe
 from moe import config
-from moe.library import LibItem, Track
+from moe.library import Album, LibItem, Track
 
 __all__ = ["write_tags"]
 
@@ -62,10 +62,13 @@ def process_new_items(items: list[LibItem]):
 
 @moe.hookimpl
 def process_changed_items(items: list[LibItem]):
-    """Writes tags to any altered tracks in the library."""
+    """Writes tags to any altered tracks or albums in the library."""
     for item in items:
-        if isinstance(item, Track):
+        if isinstance(item, Track) and item.album_obj not in items:
             write_tags(item)
+        elif isinstance(item, Album):
+            for track in item.tracks:
+                write_tags(track)
 
 
 @moe.hookimpl(tryfirst=True)
@@ -77,6 +80,8 @@ def write_custom_tags(track: Track):
     audio_file.albumartist = track.albumartist
     audio_file.artist = track.artist
     audio_file.artists = track.artists
+    audio_file.barcode = track.album_obj.barcode
+    audio_file.catalognums = track.album_obj.catalog_nums
     audio_file.country = track.album_obj.country
     audio_file.date = track.album_obj.date
     audio_file.disc = track.disc
@@ -87,6 +92,7 @@ def write_custom_tags(track: Track):
     audio_file.original_date = track.album_obj.original_date
     audio_file.title = track.title
     audio_file.track = track.track_num
+    audio_file.tracktotal = track.album_obj.track_total
 
     audio_file.save()
 
