@@ -4,6 +4,7 @@ import logging
 import re
 import shlex
 from pathlib import Path
+from typing import Type
 
 import sqlalchemy as sa
 import sqlalchemy.orm
@@ -11,6 +12,7 @@ import sqlalchemy.sql.elements
 
 from moe.config import MoeSession
 from moe.library import Album, Extra, LibItem, Track
+from moe.library.lib_item import SetType
 
 __all__: list[str] = ["QueryError", "query"]
 
@@ -32,7 +34,7 @@ by using the ``-a, --album`` option, or you can return extras using the ``-e, --
 option.
 
 If you would like to specify a value with whitespace or multiple words, enclose the
-term in quotes.
+term in quotes. Note, powershell users must use " as the outer quotes in this case.
 
 SQL LIKE query syntax is used for normal queries, which means
 the '_'  and '%' characters have special meaning:
@@ -48,7 +50,7 @@ As a shortcut to matching all entries, use '*' as the term.
 
 Finally, you can also specify any number of terms.
 For example, to match all Wu-Tang Clan tracks that start with the letter 'A', use:
-'"artist:wu-tang clan" title:a%'
+"'artist:wu-tang clan' title:a%"
 
 Note that when using multiple terms, they are joined together using AND logic, meaning
 all terms must be true to return a match.
@@ -212,33 +214,42 @@ def _create_filter_expression(field_type: str, field: str, separator: str, value
 
 def _get_field_attr(field: str, field_type: str):
     """Gets the corresponding attribute for the given field to use in a query filter."""
-    if field == "genre":
+    # convert singular multi-value fields to their plural equivalents
+    if field == "catalog_num" and field_type == "album":
+        field = "catalog_nums"
+    elif field == "genre" and field_type == "track":
         field = "genres"
 
     if field_type == "album":
-        try:
-            return getattr(Album, field)
-        except AttributeError:
-            # assume custom field
-            custom_func = sa.func.json_each(
-                Album._custom_fields, f"$.{field}"
-            ).table_valued("value", joins_implicitly=True)
-            return custom_func.c.value
+        return _getattr(Album, field)
     elif field_type == "extra":
-        try:
-            return getattr(Extra, field)
-        except AttributeError:
-            # assume custom field
-            custom_func = sa.func.json_each(
-                Extra._custom_fields, f"$.{field}"
-            ).table_valued("value", joins_implicitly=True)
-            return custom_func.c.value
+        return _getattr(Extra, field)
     else:
-        try:
-            return getattr(Track, field)
-        except AttributeError:
-            # assume custom field
-            custom_func = sa.func.json_each(
-                Track._custom_fields, f"$.{field}"
+        return _getattr(Track, field)
+
+
+def _getattr(item_class: Type[LibItem], field: str):
+    """Get an attribute for the given class type."""
+    try:
+        attr = getattr(item_class, field)
+    except AttributeError:
+        # assume custom field
+        custom_func = sa.func.json_each(
+            item_class._custom_fields, f"$.{field}"
+        ).table_valued("value", joins_implicitly=True)
+
+        return custom_func.c.value
+
+    try:
+        column_type = attr.property.columns[0].type
+    except AttributeError:
+        # hybrid_property
+        pass
+    else:
+        if isinstance(column_type, SetType):
+            multi_func = sa.func.json_each(
+                getattr(item_class, field), "$"
             ).table_valued("value", joins_implicitly=True)
-            return custom_func.c.value
+            return multi_func.c.value
+
+    return attr
